abacusai.prediction_log_record — AbacusAI documentation

# abacusai.prediction_log_record

## Classes

`PredictionLogRecord` | A Record for a prediction request log.

## Module Contents

class abacusai.prediction_log_record.PredictionLogRecord(client, requestId=None, query=None, queryTimeMs=None, timestampMs=None, response=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A Record for a prediction request log.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - requestId (str) – The unique identifier of the prediction request.

    - query (dict) – The query used to make the prediction.

    - queryTimeMs (int) – The time taken to make the prediction.

    - timestampMs (str) – The timestamp of the prediction request.

    - response (dict) – The prediction response.

  request_id
  query
  query_time_ms
  timestamp_ms
  response
  deprecated_keys
  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict